@@ -1,5 +1,22 @@
 package Objects::Collection::Item;
 
+=pod
+
+=head1 NAME
+
+ Objects::Collection::Item - Base class for objects.
+
+=head1 SYNOPSIS
+
+    use Objects::Collection::Item;
+    our @ISA = qw( Objects::Collection::Item  );
+             
+=head1 DESCRIPTION
+
+Base class for objects.
+
+=cut
+
 use strict;
 use warnings;
 use strict;
@@ -32,48 +49,23 @@ sub _changed {
 
 1;
 __END__
-# Below is stub documentation for your module. You'd better edit it!
-
-=head1 NAME
-
-Objects::Collection - Perl extension for blah blah blah
-
-=head1 SYNOPSIS
-
-  use Objects::Collection;
-  blah blah blah
-
-=head1 DESCRIPTION
-
-Stub documentation for Objects::Collection, created by h2xs. It looks like the
-author of the extension was negligent enough to leave the stub
-unedited.
-
-Blah blah blah.
 
 
 =head1 SEE ALSO
 
-Mention other useful documentation such as the documentation of
-related modules or operating system documentation (such as man pages
-in UNIX), or any relevant external documentation such as RFCs or
-standards.
-
-If you have a mailing list set up for your module, mention it here.
-
-If you have a web site set up for your module, mention it here.
+Objects::Collection::ActiveRecord, Objects::Collection, README
 
 =head1 AUTHOR
 
-Zagatski Alexandr, E<lt>zag@zagE<gt>
+Zahatski Aliaksandr, <zag@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005 by Zagatski Alexandr
+Copyright (C) 2005-2006 by Zahatski Aliaksandr
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.7 or,
+it under the same terms as Perl itself, either Perl version 5.8.8 or,
 at your option, any later version of Perl 5 you may have available.
 
-
 =cut
+
